@@ -335,6 +335,9 @@ QList<QGraphicsItem *> DiagramScene::copyItems(QList<QGraphicsItem *> source)
 void DiagramScene::moveItems(QList<QGraphicsItem *> source, QPointF delta)
 {
     foreach(QGraphicsItem* item,source){
+        if(!item->flags().testFlag(QGraphicsItem::ItemIsMovable)){
+            continue; // skip locked items
+        }
         if(item->parentItem()!=0){
             if(!item->parentItem()->isSelected()) item->moveBy(delta.x(),delta.y());
         }
@@ -374,6 +377,11 @@ qreal DiagramScene::getMinZ(QList<QGraphicsItem *> source)
 void DiagramScene::filterSelectedChildItems(QList<QGraphicsItem *> &lst)
 {
     foreach(QGraphicsItem* item,lst){
+        if(!item->flags().testFlag(QGraphicsItem::ItemIsMovable)){
+            item->setSelected(false);
+            lst.removeOne(item);
+            continue; // skip locked items
+        }
         if(item->parentItem()){
             if(item->parentItem()->isSelected()) {
                 item->setSelected(false);
@@ -803,6 +811,10 @@ void DiagramScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
     case Zoom:
         startPoint=mouseEvent->scenePos();
         break;
+    case SelectOuter:
+    case SelectInner:
+        startPoint=mouseEvent->scenePos();
+        break;
     default:
         ;
     }
@@ -899,6 +911,8 @@ void DiagramScene::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
         }
         break;
     case ZoomSingle:
+    case SelectOuter:
+    case SelectInner:
         if(m_rubberbandItem){
             m_rubberbandItem->setRect(QRectF(startPoint,mouseEvent->scenePos()));
         }
@@ -938,6 +952,22 @@ void DiagramScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent)
         }
         takeSnapshot();
     }
+    if(myMode==SelectInner || myMode==SelectOuter){
+        enableAllItems(true);
+        QPointF pt2=mouseEvent->scenePos();
+        QPainterPath path;
+        path.addRect(QRectF(startPoint,pt2));
+        QList<QGraphicsItem *> lst;
+        if(myMode==SelectInner){
+            lst=items(path,Qt::ContainsItemShape);
+        }else{
+            lst=items(path,Qt::IntersectsItemShape);
+        }
+        for(QGraphicsItem *item:lst){
+            item->setSelected(true);
+        }
+        abort(true);
+    }
     QGraphicsScene::mouseReleaseEvent(mouseEvent);
 }
 
