@@ -200,6 +200,46 @@ void MainWindow::deleteItem()
     }
     m_scene->takeSnapshot();
 }
+/*!
+ * \brief set selected items as locked
+ * Locked items can't be moved or deleted
+ */
+void MainWindow::lockItem()
+{
+    QList<QGraphicsItem *> selectedItems = m_scene->selectedItems();
+    for (int i=0;i<selectedItems.length();++i) {
+        QGraphicsItem *it=selectedItems[i];
+        DiagramItem *item=dynamic_cast<DiagramItem *>(it);
+        if(item){
+            item->setLocked(true);
+            item->setSelected(false);
+        }
+        DiagramPathItem *pathItem=dynamic_cast<DiagramPathItem *>(it);
+        if(pathItem){
+            pathItem->setLocked(true);
+            pathItem->setSelected(false);
+        }
+        DiagramSplineItem *splineItem=dynamic_cast<DiagramSplineItem *>(it);
+        if(pathItem){
+            splineItem->setLocked(true);
+            splineItem->setSelected(false);
+        }
+    }
+}
+/*!
+ * \brief unlock selected items
+ */
+void MainWindow::unlockItem()
+{
+    QList<QGraphicsItem *> selectedItems = m_scene->selectedItems();
+    for (int i=0;i<selectedItems.length();++i) {
+        QGraphicsItem *it=selectedItems[i];
+        DiagramItem *item=qgraphicsitem_cast<DiagramItem *>(it);
+        if(item){
+            item->setLocked(false);
+        }
+    }
+}
 
 void MainWindow::pointerGroupClicked(QAbstractButton *button)
 {
@@ -363,6 +403,24 @@ void MainWindow::selectAll()
         item->setSelected(true);
     }
 }
+/*!
+ * \brief start selection rectangle
+ * Only elements completely inside are selected
+ */
+void MainWindow::selectRectInner()
+{
+    m_scene->setMode(DiagramScene::SelectInner);
+    m_view->setDragMode(QGraphicsView::RubberBandDrag);
+}
+/*!
+ * \brief start selection rectangle
+ * Elements crossing rectangle are selected
+ */
+void MainWindow::selectRectOuter()
+{
+    m_scene->setMode(DiagramScene::SelectOuter);
+    m_view->setDragMode(QGraphicsView::RubberBandDrag);
+}
 
 void MainWindow::rotateRight()
 {
@@ -572,6 +630,7 @@ void MainWindow::createToolBox()
         {tr("DA"),DiagramDrawItem::DA},
         {tr("OTA"),DiagramDrawItem::OTA},
         {tr("MUX"),DiagramDrawItem::MUX},
+        {tr("DEMUX"),DiagramDrawItem::DEMUX},
         {tr("Note"),DiagramDrawItem::Note}
     };
     int row=0;
@@ -692,7 +751,7 @@ void MainWindow::createToolBox()
     }
     // add user pane !
 #ifdef Q_OS_WIN
-    const QString elementPath="%appdata%/.config/QDia/userElements";
+    const QString elementPath="%appdata%/Roaming/QDia/userElements";
    #else
     const QString elementPath=QDir::homePath()+"/.config/QDia/userElements/";
 #endif
@@ -803,6 +862,14 @@ void MainWindow::createActions()
     connect(deleteAction, &QAction::triggered, this, &MainWindow::deleteItem);
     listOfActions.append(deleteAction);
 
+    lockAction = new QAction(tr("&Lock Item"), this);
+    lockAction->setShortcut(tr("L"));
+    connect(lockAction, &QAction::triggered, this, &MainWindow::lockItem);
+
+    unlockAction = new QAction(tr("&Lock Item"), this);
+    unlockAction->setShortcut(tr("Shift+L"));
+    connect(unlockAction, &QAction::triggered, this, &MainWindow::unlockItem);
+
     exitAction = new QAction(tr("E&xit"), this);
     exitAction->setShortcuts(QKeySequence::Quit);
     exitAction->setStatusTip(tr("Quit QDia"));
@@ -814,6 +881,16 @@ void MainWindow::createActions()
     connect(selectAllAction, &QAction::triggered, this, &MainWindow::selectAll);
     listOfActions.append(selectAllAction);
 
+    selectRectOuterAction = new QAction(tr("Select Rect &Outer"), this);
+    selectRectOuterAction->setShortcut(tr("Shift+s"));
+    connect(selectRectOuterAction, &QAction::triggered, this, &MainWindow::selectRectOuter);
+    listOfActions.append(selectRectOuterAction);
+
+    selectRectInnerAction = new QAction(tr("Select &Rect Inner"), this);
+    selectRectInnerAction->setShortcut(tr("s"));
+    connect(selectRectInnerAction, &QAction::triggered, this, &MainWindow::selectRectInner);
+    listOfActions.append(selectRectInnerAction);
+
     searchAndReplaceAction = new QAction(tr("&Search and Replace Texts"), this);
     connect(searchAndReplaceAction, &QAction::triggered, this, &MainWindow::searchAndReplaceTexts);
 
@@ -849,6 +926,10 @@ void MainWindow::createActions()
     exportAction->setStatusTip(tr("Export Diagram to image"));
     connect(exportAction, SIGNAL(triggered()), this, SLOT(exportImage()));
 
+    importAction = new QAction(tr("&Import Diagram"), this);
+    importAction->setStatusTip(tr("Import Diagram from file"));
+    connect(importAction, SIGNAL(triggered()), this, SLOT(importDiagram()));
+
     copyAction = new QAction(QIcon(":/images/edit-copy.svg"),tr("&Copy"), this);
     copyAction->setShortcut(tr("c"));
     connect(copyAction, &QAction::triggered,this, &MainWindow::copyItems);
@@ -999,6 +1080,7 @@ void MainWindow::createMenus()
     fileMenu->addAction(saveAsAction);
     fileMenu->addAction(printAction);
     fileMenu->addAction(exportAction);
+    fileMenu->addAction(importAction);
     fileMenu->addAction(exitAction);
 
     editMenu = menuBar()->addMenu(tr("&Edit"));
@@ -1006,6 +1088,8 @@ void MainWindow::createMenus()
     editMenu->addAction(redoAction);
     editMenu->addSeparator();
     editMenu->addAction(selectAllAction);
+    editMenu->addAction(selectRectInnerAction);
+    editMenu->addAction(selectRectOuterAction);
     editMenu->addAction(copyToClipboardAction);
     editMenu->addAction(pasteFromClipboardAction);
     editMenu->addSeparator();
@@ -1050,6 +1134,9 @@ void MainWindow::createMenus()
     itemMenu->addAction(ungroupAction);
     itemMenu->addAction(tapAction);
     itemMenu->addAction(makeElementAction);
+    itemMenu->addSeparator();
+    itemMenu->addAction(lockAction);
+    itemMenu->addAction(unlockAction);
 
     aboutMenu = menuBar()->addMenu(tr("&Help"));
     aboutMenu->addAction(aboutAction);
@@ -1466,7 +1553,7 @@ void MainWindow::makeElement()
 
     // save selected in special path
 #ifdef Q_OS_WIN
-    QString elemenPath="%appdata%/.config/QDia/userElements";
+    QString elemenPath="%appdata%/Roaming/QDia/userElements";
 #else
     QString elemenPath=QDir::homePath()+"/.config/QDia/userElements/";
 #endif
@@ -1812,6 +1899,26 @@ void MainWindow::exportImage()
     m_scene->setCursorVisible(true);
     m_scene->setGridVisible(gridVisible);
 }
+/*!
+ * \brief Import diagram from file
+ */
+void MainWindow::importDiagram()
+{
+    QFileDialog::Options options;
+    QString selectedFilter;
+    QString path=m_lastPath.isEmpty() ? "" : m_lastPath+QDir::separator();
+    QString fileName = QFileDialog::getOpenFileName(this,
+                                                    tr("Load Diagram"),
+                                                    path+"dia.json",
+                                                    tr("QDiagram (*.qdia);;QDiagram old(*.json)"),
+                                                    &selectedFilter,
+                                                    options);
+    if (!fileName.isEmpty()){
+        // reuse user element mechanism
+        m_scene->setItemType(fileName);
+        m_scene->setMode(DiagramScene::InsertUserElement);
+    }
+}
 
 void MainWindow::zoomIn()
 {
@@ -2194,7 +2301,8 @@ void MainWindow::transformItems(const QTransform transform, QList<QGraphicsItem
     foreach( QGraphicsItem *item, items){
         if(!item) continue;
         // special treatment for texts
-        if(item->type()==DiagramTextItem::Type){
+        if(item->type()==DiagramTextItem::Type && items.count()>1){
+            // if only one item is selected, the anchor point is not moved
             if(transform==QTransform(-1,0,0,1,0,0)){
                 // flipX, text not flipped but anchorpoint moved
                 DiagramTextItem *it=qgraphicsitem_cast<DiagramTextItem*>(item);
@@ -2276,6 +2384,8 @@ void MainWindow::linePatternChanged()
 }
 
 /* TODO
+ ** color template ? / store custom colors
+ ** show handlers on top when selected and below
  * export wider to entail wider lines ?
  * user elements -> order ?
  * fix flip/rotate when moving/dragging several elements
@@ -2285,5 +2395,4 @@ void MainWindow::linePatternChanged()
  * import xcircuit/drawio?
  ** read xcircuit lps
  ** show svg
- ** flipX with shifted text
  */
