@@ -90,6 +90,8 @@ private slots:
    void redo();
    void buttonGroupClicked(QAbstractButton *button);
    void deleteItem();
+   void lockItem();
+   void unlockItem();
    void pointerGroupClicked(QAbstractButton *button);
    void horzAlignGroupClicked(QAbstractButton *button);
    void vertAlignGroupClicked(QAbstractButton *button);
@@ -98,6 +100,8 @@ private slots:
    void sendToBack();
    void sendDown();
    void selectAll();
+   void selectRectInner();
+   void selectRectOuter();
    void rotateRight();
    void rotateLeft();
    void flipX();
@@ -105,6 +109,7 @@ private slots:
    void scale();
    void print();
    void exportImage();
+   void importDiagram();
    void copyItems();
    void duplicateItems();
    void copyToClipboard();
@@ -201,6 +206,9 @@ private:
    QAction *addAction;
    QAction *deleteAction;
 
+   QAction *lockAction;
+   QAction *unlockAction;
+
    QAction *undoAction;
    QAction *redoAction;
 
@@ -212,6 +220,8 @@ private:
    QAction *bringUpAction;
    QAction *sendDownAction;
    QAction *selectAllAction;
+   QAction *selectRectInnerAction;
+   QAction *selectRectOuterAction;
    QAction *aboutAction;
    QAction *rotateRightAction;
    QAction *rotateLeftAction;
@@ -242,6 +252,7 @@ private:
 
    QAction *printAction;
    QAction *exportAction;
+   QAction *importAction;
 
    QShortcut *escShortcut;
    QShortcut *backoutOneShortcut;
